@@ -1,7 +1,11 @@
 import os
 from pathlib import Path
 import csv
+
+from tqdm import tqdm
 import numpy as np
+from scipy.spatial.distance import euclidean
+from scipy.ndimage.measurements import center_of_mass
 
 import nibabel as nib
 
@@ -11,9 +15,10 @@ def is_nifti(filename):
 
 
 def file_to_list(file_path, delimiter=' '):
-    if not os.path.exists(file_path):
-        raise ValueError(file_path + ' does not exist.')
-    if file_path.endswith('.csv'):
+    file_path = Path(file_path)
+    if not file_path.is_file():
+        raise ValueError(f'{file_path} does not exist.')
+    if file_path.name.endswith('.csv'):
         with open(file_path, 'r') as csv_file:
             dir_list = []
             for row in csv.reader(csv_file):
@@ -23,7 +28,7 @@ def file_to_list(file_path, delimiter=' '):
                     dir_list.append(row[0])
     else:
         # default delimiter is ' ', it might need to be changed
-        dir_list = np.loadtxt(file_path, dtype=str, delimiter=delimiter)
+        dir_list = np.loadtxt(str(file_path), dtype=str, delimiter=delimiter)
     return dir_list
 
 
@@ -102,7 +107,7 @@ def reorient_nifti_list(nifti_list, output_dir=None, save_in_place=False, discar
         raise Exception('output_dir does not exist or is missing. output_dir MUST be given IF save_in_place is False')
     reoriented_list = []
     failed_list = []
-    for nii in nifti_list:
+    for nii in tqdm(nifti_list, desc='Reorient Nifti list'):
         try:
             nii = load_nifti(nii)
             img = reorient_to_canonical(nii)
@@ -168,7 +173,7 @@ def resave_nifti_list(nifti_list, output_dir=None, save_in_place=False, discard_
     ----------
     nifti_list : list of nibabel.Nifti1Image or list of path-like object
     output_dir : path-like object
-        optional is save_in_place is True. If given, the reoriented images will be saved in the output directory
+        optional if save_in_place is True. If given, the reoriented images will be saved in the output directory
     save_in_place : bool
         save the reoriented images in place of the input images
     discard_errors : bool
@@ -200,3 +205,65 @@ def resave_nifti_list(nifti_list, output_dir=None, save_in_place=False, discard_
             else:
                 raise TypeError('Error in file {}: {}'.format(fname, e))
     return resaved_list, failed_list
+
+
+def get_centre_of_mass(nifti, round_coord=False):
+    nii = load_nifti(nifti)
+    if not np.array(nii.get_fdata()).any():
+        return tuple(np.zeros(len(nii.shape)))
+    if round_coord:
+        return np.round(center_of_mass(np.nan_to_num(np.abs(nii.get_fdata()))))
+    else:
+        return center_of_mass(np.nan_to_num(np.abs(nii.get_fdata())))
+
+
+def centre_of_mass_difference(nifti, reference, round_centres=False):
+    if not (isinstance(reference, list) or isinstance(reference, tuple) or isinstance(reference, set)):
+        reference = get_centre_of_mass(reference, round_centres)
+    nii_centre = get_centre_of_mass(nifti, round_centres)
+    if len(nii_centre) != len(reference):
+        raise ValueError('Nifti image ({}) and reference ({}) must have the same number of dimensions'.format(
+            nii_centre, reference))
+    return euclidean(nii_centre, reference)
+
+
+def centre_of_mass_difference_list(nifti_list, reference, fname_filter=None, round_centres=False):
+    if fname_filter is not None:
+        nifti_list = [f for f in nifti_list if fname_filter in Path(f).name]
+    distance_dict = {}
+    for f in nifti_list:
+        distance_dict[str(f)] = centre_of_mass_difference(f, reference, round_centres)
+    return distance_dict
+
+
+def nifti_overlap_images(input_images, filter_pref=''):
+    if not isinstance(input_images, list):
+        if Path(input_images).is_file():
+            input_images = [str(p) for p in file_to_list(input_images) if is_nifti(p)]
+        elif Path(input_images).is_dir():
+            input_images = [str(p) for p in Path(input_images).iterdir() if is_nifti(p)]
+        else:
+            raise ValueError('Wrong input (must be a file/directory path of a list of paths)')
+    if filter_pref:
+        input_images = [p for p in input_images if Path(p).name.startswith(filter_pref)]
+    if not input_images:
+        raise ValueError('The image list is empty, either "input_images" is empty or "filter_pref" was not found'
+                         ' in the paths')
+    temp_overlap = None
+    temp_overlap_data = None
+    for img in tqdm(input_images):
+        nii = nib.load(img)
+        if temp_overlap is None:
+            temp_overlap = nii
+            temp_overlap_data = nii.get_fdata()
+        else:
+            temp_overlap_data += nii.get_fdata()
+    temp_overlap = nib.Nifti1Image(temp_overlap_data, temp_overlap.affine)
+    return temp_overlap
+
+
+def overlaps_subfolders(root_folder, filter_pref=''):
+    for subfolder in [p for p in Path(root_folder).iterdir() if p.is_dir()]:
+        print(f'Overlap of [{subfolder.name}]')
+        overlap_path = Path(root_folder, 'overlap_' + subfolder.name + '.nii')
+        nib.save(nifti_overlap_images(subfolder, filter_pref), overlap_path)
